@@ -159,7 +159,14 @@ setMethod("check_nifti", "ANY",
                    need_header = TRUE) {
             # workaround because can't get class
             if (inherits(x, "niftiImage")) {
-              x = oro.nifti::nii2oro(x)
+              if (!allow.array) {
+                x = oro.nifti::nii2oro(x)
+              }
+            } else if (inherits(x, "NiftiArray")) {
+              if (!allow.array) {
+                x = methods::as(x, "niftiImage")
+                x = oro.nifti::nii2oro(x)
+              }
             } else {
               stop("Not implemented for this type!")
             }
