@@ -9,9 +9,7 @@
 #' @param replace Value to replace non-finite values to
 #' @export 
 #' @author John Muschelli \email{muschellij2@@gmail.com} 
-setGeneric("finite_img", function(img, replace = 0) {
-  standardGeneric("finite_img")
-})
+setGeneric("finite_img", function(img, replace = 0) standardGeneric("finite_img"))
 
 #' @rdname finite_img-methods
 #' @aliases finite_img,nifti-method
@@ -22,6 +20,14 @@ setMethod("finite_img", "nifti", function(img, replace = 0) {
   return(img)
 })
 
+#' @rdname finite_img-methods
+#' @aliases finite_img,array-method
+#' @export
+setMethod("finite_img", "array", function(img, replace = 0) { 
+  img[ !is.finite(img) ] = replace
+  return(img)
+})
+
 #' @rdname finite_img-methods
 #' @aliases finite_img,ANY-method
 #' @export
